
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure1.m                                                               %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 1                                                          %
%                                                                         %
%   required input files:                                                 %
%       figure1_data.mat                                                  %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc

set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

spacing = [.3 0.01];
load figure1_data.mat

%%

figure(1);
clf
subplot_tight(1,5,2,spacing)
plot(0*U2+30,z3/1000,'k-','linewidth',2)
hold on
plot(U,z1/1000,'r-','linewidth',2)
plot(U2,z3/1000,'b-','linewidth',2)
plot(0*U2+30,z3/1000,'k-','linewidth',2)
ylim([79 81])   
xlim([15 45])
xlabel('$\overline{U}$ (ms$^{-1}$)','fontsize',15)
ylabel('Alt (km)','fontsize',15)
grid on
set(gca,'fontsize',18,'xtick',0:10:40,'TickLabelInterpreter', 'latex')
legend({'Cases 1-2', 'Cases 3-4', 'Cases 5-6'},'location','southwest','interpreter','latex','fontsize',14)
set(gca,'TickLabelInterpreter', 'latex');


subplot_tight(1,5,3,spacing)
plot(0.*du_dz,z1/1000,'k-','linewidth',2)
hold on
plot(1000*du_dz.^2,z1/1000,'b-','linewidth',2)
plot(0.*du_dz,z1/1000,'k-','linewidth',2)
ylim([79 81])   
xlabel('$\overline{U}_z^2$ (s$^{-2}$)','fontsize',15)
grid on
set(gca,'fontsize',18,'yticklabels',[],'xtick',[0,1.5],'xticklabels',{'0','$1.5\times10^{-3}$'})
xlim([-.5 2])
legend({'Cases 1-2', 'Cases 3-6'},'location','south','interpreter','latex','fontsize',14)
set(gca,'TickLabelInterpreter', 'latex');


subplot_tight(1,5,4,spacing)
plot(4+0*N_Squared,z1/1000,'k-','linewidth',2)
hold on
plot(10000*N_Squared,z1/1000,'k:','linewidth',2)
axis([3 9 79 81])   
xlabel('$N^2$  (s$^{-2}$)','fontsize',15)
set(gca,'fontsize',18,'xtick',4:4:10,'yticklabels',[], 'xticklabels',{'$4\times10^{-4}$','$8\times 10^{-4}$'},'TickLabelInterpreter', 'latex')
grid on
legend({'Cases 1,3,5', 'Cases 2,4,6'},'location','south','interpreter','latex','fontsize',14)
set(gca,'TickLabelInterpreter', 'latex');


subplot_tight(1,5,5,spacing)
plot(Ri2,z1/1000,'b-','linewidth',2)
hold on
plot(Ri,z1/1000,'b:','linewidth',2)
axis([0 1 78 82])
xlabel('$Ri$','fontsize',15)
grid on
set(gca,'fontsize',18,'xtick',0:.25:1,'yticklabels',[],'xticklabels',{0,0.25,.5,.75,1},'TickLabelInterpreter', 'latex')
legend({'Cases 3 and 5','Cases 4 and 6'},'location','southeast','interpreter','latex','fontsize',14)
set(gca,'TickLabelInterpreter', 'latex');
