
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure11.m                                                              %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 11                                                         %
%                                                                         %
%   required input files:                                                 %
%       figure11_data.mat                                                 %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc
   
set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

load figure11_data.mat

spacing = [.005 0];
clims_theta = [-0.1626 0.1626];
clims_vort = [-6 0.9574];
clims_vort_y = [-.15 .15];
clims_u = [-60 60];
clims_w = [-50 50];
clims_solenoid = [-1E-3 1E-3];
altmin = 75;
altmax = 85;

factor_pos_shear = [4.5 4 3.8];
factor_n2 = [6.5 6 5.3];
factor_neg_shear = [8.7 6.4 5.2];

du_factor = [4 3.5 3];


clims_shear = [0 .1]; 
clims_n2 = [0 .002];
dim1{1} = [0.127 0.573 0.1 0.3];
dim1{2} = [0.252 0.573 0.1 0.3];
dim1{3} = [0.377 0.573 0.1 0.3];
dim1{4} = [0.502 0.573 0.1 0.3];
dim1{5} = [0.627 0.573 0.1 0.3];
dim1{6} = [0.752 0.573 0.1 0.3];

dim2{1} = [0.127 0.45 0.1 0.3];
dim2{2} = [0.252 0.45 0.1 0.3];
dim2{3} = [0.377 .45 0.1 0.3];
dim2{4} = [0.502 .45 0.1 0.3];
dim2{5} = [0.627 .45 0.1 0.3];
dim2{6} = [0.752 .45 0.1 0.3];

dim3{1} = [0.127 .325 0.1 0.3];
dim3{2} = [0.252 .325 0.1 0.3];
dim3{3} = [0.377 .325 0.1 0.3];
dim3{4} = [0.502 .325 0.1 0.3];
dim3{5} = [0.627 .325 0.1 0.3];
dim3{6} = [0.752 .325 0.1 0.3];

dim4{1} = [0.127 .5 0.001 0.001];
dim4{2} = [0.252 .5 0.001 0.001];
dim4{3} = [0.377 .5 0.001 0.001];
dim4{4} = [0.502 .5 0.001 0.001];
dim4{5} = [0.627 .5 0.001 0.001];
dim4{6} = [0.752 .5 0.001 0.001];

dim5{1} = [0.127 .375 0.001 0.001];
dim5{2} = [0.252 .375 0.001 0.001];
dim5{3} = [0.377 .375 0.001 0.001];
dim5{4} = [0.502 .375 0.001 0.001];
dim5{5} = [0.627 .375 0.001 0.001];
dim5{6} = [0.752 .375 0.001 0.001];

dim6{1} = [0.127 .25 0.001 0.001];
dim6{2} = [0.252 .25 0.001 0.001];
dim6{3} = [0.377 .25 0.001 0.001];
dim6{4} = [0.502 .25 0.001 0.001];
dim6{5} = [0.627 .25 0.001 0.001];
dim6{6} = [0.752 .25 0.001 0.001];

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];
colormap(map); 

num_files = 3;

for i = 1:num_files


    subplot_tight(8,8,34+i,spacing)
    surf(xgrid/1000,alt_case4/1000,-vort_y_case4(:,:,i),'FaceColor','interp','Edgecolor','none')
    caxis(clims_vort_y);
    colormap(map); 
    hold on
    temp = temp_case4(:,:,i);
    plot(24+temp(temp > 0), alt_cs(temp > 0)/1000,'r.')
    hold on
    plot(24+temp(temp < 0), alt_cs(temp < 0)/1000,'b.')
    x0=[24 24];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',.3); hold on;
    x0=[20.075 20.075];y0=[altmin altmax];plot(x0,y0,'k-','Linewidth',.3); hold on;
    ylim([altmin altmax]) 
    xlim([0 28]) 
    
    if i == 1
        str1 = {'6.5 $T_B$'};
    elseif i == 2
        str1 = {'7.5 $T_B$'};
    elseif i == 3
        str1 = {'8.5 $T_B$'};
    end
    annotation('textbox',dim4{i+1},'String',str1,'FitBoxToText','on',...
        'interpreter','latex','fontsize',12,'Edgecolor','none');
    set(gca,'fontsize',10,'xtick',[0,5,10,15,20.075,21,24,27],'ytick',77:3:83,'xticklabels',' ')
    grid off
    box on
    set(gca,'layer','top','LineWidth',0.3,'xticklabels',[]);
    if i == 1
        ylabel('Alt (km)','fontsize',12) 
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('Case 4','color',[0,0,0],'fontsize',12);
        set(gca,'ytick',77:3:83);
        set(gca,'yticklabels',[]);
    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90)
    xlabel('$\zeta_y$', 'fontsize',14)
end

for i = 1:num_files
        
% first row of plots
%    subplot_tight(8,8,10+i,spacing)
% second row of plots
%    subplot_tight(8,8,18+i,spacing)
% third row of plots
    subplot_tight(8,8,26+i,spacing)
% fourth row of plots    
%    subplot_tight(8,8,34+i,spacing)
    
    surf(xgrid/1000,alt_cases/1000,-vort_y_case3(:,:,i),'FaceColor','interp','Edgecolor','none')
    caxis(clims_vort_y);
    colormap(map); 
    hold on
    temp = temp_case3(:,:,i); 
    plot(24+temp(temp > 0), alt_cs(temp > 0)/1000,'r.')
    hold on
    plot(24+temp(temp < 0), alt_cs(temp < 0)/1000,'b.')
    x0=[24 24];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',.3); hold on;
    x0=[20.075 20.075];y0=[altmin altmax];plot(x0,y0,'k-','Linewidth',.3); hold on;   
    ylim([altmin altmax]) 
    xlim([0 28]) 
    if i == 1
        str1 = {'6.5 $T_B$'};
    elseif i == 2
        str1 = {'7.5 $T_B$'};
    elseif i == 3
        str1 = {'8.5 $T_B$'};
    end
    annotation('textbox',dim3{i+1},'String',str1,'FitBoxToText','on',...
    'interpreter','latex','fontsize',12,'Edgecolor','none');
    set(gca,'fontsize',10,'xtick',[0,5,10,15,20.075,21,24,27],'ytick',77:3:83,'xticklabels',' ')
    if i == 1
        set(gca,'xticklabels',{'','-5','0','5','','-.75','0','.75'});
    end        
    if i == 2
        set(gca,'xticklabels',{'','-5','0','5','','-.86','0','.86'});
    end  
    if i == 3
        set(gca,'xticklabels',{'','-5','0','5','','-1','0','1'});
    end    
    grid off
    box on
    set(gca,'layer','top','LineWidth',0.3,'xticklabels',[]);
    if i == 1
        ylabel('Alt (km)','fontsize',12) 
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('Case 3','color',[0,0,0],'fontsize',12);
        set(gca,'ytick',77:3:83);
        set(gca,'yticklabels',[]);

    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90)
end

figure(2)
clf

for i = 1:num_files
    subplot_tight(8,8,42+i,spacing) 
    surf(xgrid/1000,alt_cases/1000,-vort_y_case5(:,:,i),'FaceColor','interp','Edgecolor','none')
    caxis(clims_vort_y);
    colormap(map); 
    hold on
    temp = temp_case5(:,:,i); % redefine from saved variable 
    plot(24+temp(temp > 0), alt_cs(temp > 0)/1000,'r.')
    hold on
    plot(24+temp(temp < 0), alt_cs(temp < 0)/1000,'b.')
    x0=[24 24];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',.3); hold on;
    x0=[20.075 20.075];y0=[altmin altmax];plot(x0,y0,'k-','Linewidth',.3); hold on;    
    ylim([altmin altmax]) 
    xlim([0 28]) 
    if i == 1
        str1 = {'4.5 $T_B$'};
    elseif i == 2
        str1 = {'5.5 $T_B$'};
    elseif i == 3
        str1 = {'6.5 $T_B$'};
    end
    annotation('textbox',dim5{i+1},'String',str1,'FitBoxToText','on',...
        'interpreter','latex','fontsize',12,'Edgecolor','none');
    set(gca,'fontsize',10,'xtick',[5,10,15,20.075],'ytick',77:3:83,'xticklabels',' ')
    grid off
    box on
    set(gca,'layer','top','LineWidth',0.3,'xticklabels',[]);
    if i == 1
        ylabel('Alt (km)','fontsize',12) 
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('Case 5','color',[0,0,0],'fontsize',12);
        set(gca,'ytick',77:3:83);
        set(gca,'yticklabels',[]);
    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90)
    
    clearvars('vort_y', 'theta_prime','u_prime','w_prime','p_prime','vort_mag','theta_prime','rho_prime','u_full','shear','theta_full','n2','u_full_vort','w_full_vort')
end


for i = 1:num_files

    subplot_tight(8,8,50+i,spacing) 
    surf(xgrid/1000,alt_cases/1000,-vort_y_case6(:,:,i),'FaceColor','interp','Edgecolor','none')
    caxis(clims_vort_y);
    colormap(map); 
    hold on
    temp = temp_case6(:,:,i); % redefine from saved variable 
    plot(24+temp(temp > 0), alt_cs(temp > 0)/1000,'r.')
    hold on
    plot(24+temp(temp < 0), alt_cs(temp < 0)/1000,'b.')
    x0=[24 24];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',.3); hold on;
    x0=[20.075 20.075];y0=[altmin altmax];plot(x0,y0,'k-','Linewidth',.3); hold on;   
     ylim([altmin altmax]) 
     xlim([0 28]) 
    if i == 1
        str1 = {'4.5 $T_B$'};
    elseif i == 2
        str1 = {'5.5 $T_B$'};
    elseif i == 3
        str1 = {'6.5 $T_B$'};
    end
    annotation('textbox',dim6{i+1},'String',str1,'FitBoxToText','on',...
        'interpreter','latex','fontsize',12,'Edgecolor','none');
    set(gca,'fontsize',10,'xtick',[0,5,10,15,20.075,21,24,27],'ytick',77:3:83)
    if i == 1
        set(gca,'xticklabels',{'','-5','0','5','','-.75','0','.75'});
    end        
    if i == 2
        set(gca,'xticklabels',{'','-5','0','5','','-.86','0','.86'});
    end  
    if i == 3
        set(gca,'xticklabels',{'','-5','0','5','','-1','0','1'});
    end       
    grid off
    box on
    set(gca,'layer','top','LineWidth',0.3);
    if i == 1
        ylabel('Alt (km)','fontsize',12) 
    end
    if i > 1
        set(gca,'yticklabels',[]);

    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('Case 6','color',[0,0,0],'fontsize',12);
        set(gca,'ytick',77:3:83);
        set(gca,'yticklabels',[]);

    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90)
    xlabel('$\Delta \overline{U}_{rel}$', 'fontsize',14)
end    