
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure12.m                                                              %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 12                                                         %
%                                                                         %
%   required input files:                                                 %
%       figure12_data.mat                                                 %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc
   
set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

load figure12_data.mat

alt_low = 77000;
alt_high = 83000;

spacing = [.2 .03];
spacing2 = [.2 .01];

clims_theta = [-0.1626 0.1626];
clims_vort = [-6 0.9574];
clims_vort_y = [-.15 .15];
clims_u = [-60 60];
clims_w = [-50 50];
clims_solenoid = [-1E-3 1E-3];
clims_shear = [0 .1];
clims_n2 = [0 .002];
dim1{1} = [0.127 0.67 0.1 0.3];
dim1{2} = [0.252 0.67 0.1 0.3];
dim1{3} = [0.377 0.67 0.1 0.3];
dim1{4} = [0.502 0.67 0.1 0.3];
dim1{5} = [0.627 0.67 0.1 0.3];
dim1{6} = [0.752 0.67 0.1 0.3];

dim2{1} = [0.127 0.525 0.1 0.3];
dim2{2} = [0.252 0.525 0.1 0.3];
dim2{3} = [0.377 0.525 0.1 0.3];
dim2{4} = [0.502 0.525 0.1 0.3];
dim2{5} = [0.627 0.525 0.1 0.3];
dim2{6} = [0.752 0.525 0.1 0.3];

dim3{1} = [0.127 .358 0.1 0.3];
dim3{2} = [0.252 .358 0.1 0.3];
dim3{3} = [0.377 .358 0.1 0.3];
dim3{4} = [0.502 .358 0.1 0.3];
dim3{5} = [0.627 .358 0.1 0.3];
dim3{6} = [0.752 .358 0.1 0.3];

dim4{1} = [0.127 .49 0.001 0.001];
dim4{2} = [0.252 .49 0.001 0.001];
dim4{3} = [0.377 .49 0.001 0.001];
dim4{4} = [0.502 .49 0.001 0.001];
dim4{5} = [0.627 .49 0.001 0.001];
dim4{6} = [0.752 .49 0.001 0.001];

dim5{1} = [0.127 .326 0.001 0.001];
dim5{2} = [0.252 .326 0.001 0.001];
dim5{3} = [0.377 .326 0.001 0.001];
dim5{4} = [0.502 .326 0.001 0.001];
dim5{5} = [0.627 .326 0.001 0.001];
dim5{6} = [0.752 .326 0.001 0.001];

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];
colormap(map); 

for i = 2:2:4

    
    fs = 102.4003; % 10m sampling in x, or .01km
    pxx_tot = zeros(1025,1);
    alt = alt_cases;
    u_prime = u_prime_case1(:,:,i);
    
    for pind = 1:length(alt)
        [pxx_new,f] = periodogram(u_prime(:,pind),[],[],fs);
        pxx_tot = pxx_tot + pxx_new;
    end
    
    subplot_tight(1,4.5,i+.2,spacing2)
    loglog(f,pxx_tot./length(alt),'k-','linewidth',2)
    xlim([.05 fs/2+1]); ylim([10^-8 20])
    xlabel('$k/2\pi$ (cycles/km')
    hold on    
      
    pxx_tot = zeros(1025,1);
    alt = alt_cases;
    u_prime = u_prime_case2(:,:,i);    
    
    for pind = 1:length(alt)
        [pxx_new,f] = periodogram(u_prime(:,pind),[],[],fs);
        pxx_tot = pxx_tot + pxx_new;
    end
    
    loglog(f,pxx_tot./length(alt),'k:','linewidth',2)
    xlim([.05 fs/2+1]); ylim([10^-8 20])
    xlabel('$k/2\pi$ (cycles/km)')
    hold on
   
    pxx_tot = zeros(1025,1);
    alt = alt_cases;
    u_prime = u_prime_case3(:,:,i);

    for pind = 1:length(alt)
        [pxx_new,f] = periodogram(u_prime(:,pind),[],[],fs);
        pxx_tot = pxx_tot + pxx_new;
    end
    
    loglog(f,pxx_tot./length(alt),'r-','linewidth',2)
    xlim([.05 fs/2+1]); ylim([10^-8 20])
    xlabel('$k/2\pi$ (cycles/km)')
    hold on
    
    pxx_tot = zeros(1025,1);
    alt = alt_case4;
    u_prime = u_prime_case4(:,:,i);
    
    for pind = 1:length(alt)
        [pxx_new,f] = periodogram(u_prime(:,pind),[],[],fs);
        pxx_tot = pxx_tot + pxx_new;
    end
    
    loglog(f,pxx_tot./length(alt),'r:','linewidth',2)
    xlim([.05 fs/2+1]); ylim([10^-8 20])
    xlabel('$k/2\pi$ (cycles/km)')
    hold on
    
    pxx_tot = zeros(1025,1);
    alt = alt_cases;
    u_prime = u_prime_case5(:,:,i);

    for pind = 1:length(alt)
        [pxx_new,f] = periodogram(u_prime(:,pind),[],[],fs);
        pxx_tot = pxx_tot + pxx_new;
    end
 
    loglog(f,pxx_tot./length(alt),'b-','linewidth',2)
    xlim([.05 fs/2+1]); ylim([10^-8 20])
    xlabel('$k/2\pi$ (cycles/km)')
    hold on
 
    pxx_tot = zeros(1025,1);
    alt = alt_cases;
    u_prime = u_prime_case6(:,:,i);

    for pind = 1:length(alt)
        [pxx_new,f] = periodogram(u_prime(:,pind),[],[],fs);
        pxx_tot = pxx_tot + pxx_new;
    end
    
    loglog(f,pxx_tot./length(alt),'b:','linewidth',2)
    xlim([.05 fs/2+1]); ylim([10^-8 20])
    xlabel('$k/2\pi$ (cycles/km)')
    hold on
 
    if i == 1
        xlim([.05 fs/2+1])
        ylim([10^-6 10^4])
        title('$T=5.5\ T_B$','fontsize',15)
        ylabel('$F_{u''}\ (k)$','fontsize',15)
        legend({'Case 1', 'Case 2', 'Case 3', 'Case 4', 'Case 5', 'Case 6'},'Interpreter','Latex','location','northeast')
        set(gca,'fontsize',12) 
        grid on
        box on
    elseif i == 2
        grid on
        xlim([.05 fs/2+1])
        ylim([10^-6 10^4])         
        ylabel('$F_{u''}$ (k)','fontsize',15)
        title('$T=6.5\ T_B$','fontsize',15)
        set(gca,'fontsize',12,'yticklabels',' ') 
        grid on
        box on
        legend({'Case 1', 'Case 2', 'Case 3', 'Case 4', 'Case 5', 'Case 6'},'Interpreter','Latex','location','northeast')
    elseif i == 3
        xlim([.05 fs/2+1])
        ylim([10^-6 10^4])  
        title('$T=7.5\ T_B$','fontsize',15)
        set(gca,'fontsize',12,'yticklabels',' ') 
        grid on
        box on
    elseif i == 4
        xlim([.05 fs/2+1])
        ylim([10^-6 10^4])  
        title('$T=8.5\ T_B$','fontsize',15)
        set(gca,'fontsize',12,'yticklabels',' ') 
        grid on
        box on
    
        % 3 -5/3 lines only
        loglog(f,25*f.^(-5/3),'k--')
        loglog(f,2.5*f.^(-5/3),'k--')
        loglog(f,.25*f.^(-5/3),'k--')
        
        % 3 -7 lines only
        loglog(f,70000*f.^(-7),'k--')
        loglog(f,7000000*f.^(-7),'k--')
        loglog(f,700000000*f.^(-7),'k--')
    end  
end    
       
   