
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure2.m                                                               %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 2                                                          %
%                                                                         %
%   required input files:                                                 %
%       figure2_data.mat                                                  %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc
   
set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

load figure2_data.mat
spacing = [.015 0];
clims_theta = [-0.1626 0.1626];
clims_vort = [-6 0.9574];
clims_vort_y = [-.15 .15];
clims_u = [-60 60];
clims_w = [-30 30];
clims_solenoid = [-1E-3 1E-3];

clims_shear = [0 .1]; 
clims_n2 = [0 .002];
dim{1} = [0.125 0.67 0.1 0.3];
dim{2} = [0.25 0.67 0.1 0.3];
dim{3} = [0.375 0.67 0.1 0.3];
dim{4} = [0.5 0.67 0.1 0.3];
dim{5} = [0.625 0.67 0.1 0.3];
dim{6} = [0.75 0.67 0.1 0.3];

dim2{1} = [0.125 0.477 0.1 0.3];
dim2{2} = [0.25 0.477 0.1 0.3];
dim2{3} = [0.375 0.477 0.1 0.3];
dim2{4} = [0.5 0.477 0.1 0.3];
dim2{5} = [0.625 0.477 0.1 0.3];
dim2{6} = [0.75 0.477 0.1 0.3];

dim3{1} = [0.125 0.283 0.1 0.3];
dim3{2} = [0.25 0.283 0.1 0.3];
dim3{3} = [0.375 0.283 0.1 0.3];
dim3{4} = [0.5 0.283 0.1 0.3];
dim3{5} = [0.625 0.283 0.1 0.3];
dim3{6} = [0.75 0.283 0.1 0.3];

dim4{1} = [0.125 0.388 0.001 0.001];
dim4{2} = [0.25 0.388 0.001 0.001];
dim4{3} = [0.375 0.388 0.001 0.001];
dim4{4} = [0.5 0.388 0.001 0.001];
dim4{5} = [0.625 0.388 0.001 0.001];
dim4{6} = [0.75 0.388 0.001 0.001];

dim5{1} = [0.125 0.193 0.001 0.001];
dim5{2} = [0.25 0.193 0.001 0.001];
dim5{3} = [0.375 0.193 0.001 0.001];
dim5{4} = [0.5 0.193 0.001 0.001];
dim5{5} = [0.625 0.193 0.001 0.001];
dim5{6} = [0.75 0.193 0.001 0.001];

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];

colormap(map); 

%%

figure(1);
clf

num_files = 4;


for i = 1:num_files
    
    subplot_tight(3,8,1+i,spacing)
    surf(xgrid/1000,alt/1000,u_prime_plot(:,:,i)','FaceColor','interp','Edgecolor','none')
    caxis(clims_u);
    colormap(map); 
    ylim([65 95])  
    xlim([0 20])
    str1 = {[num2str(round(time(file_time(i))./314,2,'significant')),' $T_B$']};
    annotation('textbox',dim{i},'String',str1,'FitBoxToText','on',...
        'interpreter','latex','fontsize',15,'EdgeColor','none');
    set(gca,'fontsize',10,'xtick',5:5:20,'ytick',60:5:95)
    set(gca,'layer','top','xticklabels',[])
    grid off
    box on
    if i == 1
        ylabel('Alt (km)','fontsize',14) 
        set(gca,'xtick',0:5:20)
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
        
    if i == num_files 
        c = colorbar;
        c.FontSize = 10;
        c.Location = 'west';
        c.Label.String = 'u'' (ms$^{-1}$)'; 
        c.Label.FontSize = 14;
        c.Label.FontWeight = 'bold';
        c.Label.Interpreter = 'latex';
        set(gca,'ytick',70:5:90);
    end
    
    ax = gca;
    ax.MinorGridAlpha = 0.3;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    ax.MinorGridColor = [0 0 0];
    view(0,90)

    
    subplot_tight(3,8,9+i,spacing)
    surf(xgrid/1000,alt/1000,w_prime_plot(:,:,i)','FaceColor','interp','Edgecolor','none')
    caxis(clims_w);
    colormap(map); 
    ylim([65 95])  
    xlim([0 20]) 
    if i == 1
        ylabel('Alt (km)','fontsize',14) 
        xlabel('Streamwise Domain (km)','fontsize',14) 
        set(gca,'xtick',0:5:20)
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        c = colorbar;
        c.FontSize = 10;
        c.Location = 'west';
        c.Label.String = 'w'' (ms$^{-1}$)'; 
        c.Label.FontSize = 14;
        c.Label.FontWeight = 'bold';
        c.Label.Interpreter = 'latex';
    end
     ax = gca;
     ax.XColor = [0 0 0];
     ax.YColor = [0 0 0];
     view(0,90)
    set(gca,'layer','top')
     grid off
     box on
    if i == 1
        set(gca,'xticklabels',{'0','5','10','15','20'})
    else
        set(gca,'xticklabels',{' ','5','10','15','20'})
    end    
end

