
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure4.m                                                               %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 4                                                          %
%                                                                         %
%   required input files:                                                 %
%       figure4_data.mat                                                  %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc

set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

tmin = .3;
tmax = 16;
altmin = 30;
altmax = 100;
timedel = 2;
spacing = [.14,.06];
spacing2 = [.08,.035];
sp_ax = .02;

dim1 = [0.035 0.615 0.1 0.3];
dim2 = [0.52 0.615 0.1 0.3];
dim3 = [0.035 0.155 0.1 0.3];
dim4 = [0.52 0.155 0.1 0.3];


load figure4_data.mat

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];



%%
figure(1)
clf

subplot_tight(1,6,[1.5 5],[.1,.05])
plot(diff1_norm(1:5:end),alt_constant_sampling(1:5:end)./1000,'ko','Linewidth',2,'markersize',4)
hold on
plot(2 + diff2_norm,alt_constant_sampling./1000,'k:','Linewidth',2)
plot(5 + diff3_norm,alt_constant_sampling./1000,'k--','Linewidth',2)
plot(8 + diff4_norm,alt_constant_sampling./1000,'k-','Linewidth',2)
ax = gca;
ax.ColorOrderIndex = 1;

x0=[0 0];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',1); hold on;
x0=[2 2];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',1); hold on;
x0=[5 5];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',1); hold on;
x0=[8 8];y0=[altmin altmax];plot(x0,y0,'k--','Linewidth',1); hold on;

ylim([40 95])
xlim([-1 8.5])
set(gca,'fontsize',15)
grid on
set(gca,'fontsize',15,'xtick',-1:1:8,'ytick',10:5:100,'xticklabels',{-1,0,-1,0,-2,-1,0,-2,-1,0})
xlabel('$\Delta \overline{u}/U_0$','fontsize',25)
ylabel('Alt (km)','fontsize',25)
ax1 = gca; 
ax1_pos = ax1.Position; 
ax2 = axes('Position',ax1_pos,...
'XAxisLocation','top',...
'YAxisLocation','right',...
'Color','none');
ax2 = gca;
xlim(ax2,[-1 8.5])
set(gca,'layer','top','xtick',-1:1:8,'xticklabels',{' ','$T=2.5\ T_B$',' ','$3.7\ T_B$',' ',' ','$6.7\ T_B$',' ',' ','$10\ T_B$'},'ytick',10:5:100,'fontsize',25,'ticklabelinterpreter','latex')
drawnow

subplot_tight(1,5,5,[.1 .01])
hold on
plot(diff1(1:5:end)./max(abs(diff1(:))),alt_constant_sampling(1:5:end)./1000,'ko','Linewidth',2,'markersize',4)
plot(diff2./max(abs(diff2(:))),alt_constant_sampling./1000,'k:','Linewidth',2)
plot(diff3./max(abs(diff3(:))),alt_constant_sampling./1000,'k--','Linewidth',2)
plot(diff4./max(abs(diff4(:))),alt_constant_sampling./1000,'k-','Linewidth',2)
ax = gca;
ax.ColorOrderIndex = 1;
ylim([40 95])
xlim([-1.05 .05])
set(gca,'fontsize',15)
grid on
box on
set(gca,'fontsize',15,'xtick',-2:.25:9,'ytick',10:5:100,'yticklabels',' ')
xlabel('$\Delta \overline{u}/\Delta \overline{u}_{max}$','fontsize',25)

