
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure6_tl.m                                                            %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 6 top left panels                                          %
%                                                                         %
%   required input files:                                                 %
%       figure6tl_data.mat                                                %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc
   
set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

load figure6tl_data.mat

spacing = [.005 0];
clims_theta = [-0.1626 0.1626];
clims_vort = [-6 0.9574];
clims_vort_y = [-.15 .15];
clims_u = [-60 60];
clims_w = [-50 50];
clims_solenoid = [-1E-3 1E-3];
clims_shear = [0 .1]; 
clims_n2 = [0 .002];

dim1{1} = [0.125 0.67 0.1 0.3];
dim1{2} = [0.25 0.67 0.1 0.3];
dim1{3} = [0.375 0.67 0.1 0.3];
dim1{4} = [0.5 0.67 0.1 0.3];
dim1{5} = [0.625 0.67 0.1 0.3];
dim1{6} = [0.75 0.67 0.1 0.3];

dim2{1} = [0.125 0.525 0.1 0.3];
dim2{2} = [0.25 0.525 0.1 0.3];
dim2{3} = [0.375 0.525 0.1 0.3];
dim2{4} = [0.5 0.525 0.1 0.3];
dim2{5} = [0.625 0.525 0.1 0.3];
dim2{6} = [0.75 0.525 0.1 0.3];

dim3{1} = [0.125 .358 0.1 0.3];
dim3{2} = [0.25 .358 0.1 0.3];
dim3{3} = [0.375 .358 0.1 0.3];
dim3{4} = [0.5 .358 0.1 0.3];
dim3{5} = [0.625 .358 0.1 0.3];
dim3{6} = [0.75 .358 0.1 0.3];

dim4{1} = [0.125 .49 0.001 0.001];
dim4{2} = [0.25 .49 0.001 0.001];
dim4{3} = [0.375 .49 0.001 0.001];
dim4{4} = [0.5 .49 0.001 0.001];
dim4{5} = [0.625 .49 0.001 0.001];
dim4{6} = [0.75 .49 0.001 0.001];

dim5{1} = [0.125 .326 0.001 0.001];
dim5{2} = [0.25 .326 0.001 0.001];
dim5{3} = [0.375 .326 0.001 0.001];
dim5{4} = [0.5 .326 0.001 0.001];
dim5{5} = [0.625 .326 0.001 0.001];
dim5{6} = [0.75 .326 0.001 0.001];


min_x = [0 15 10 5];
max_x = [20 35 30 25];

min_y = [76 76 76 76];
max_y = [83 83 83 83];

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];
colormap(map); 

num_files = 4;

figure(1);
clf

for i = 3:num_files
    

% first row of plots
%    subplot_tight(6,8,10+i,spacing)
% second row of plots
%    subplot_tight(6,8,18+i,spacing)
% third row of plots
%    subplot_tight(6,8,26+i,spacing)
% fourth row of plots    
    subplot_tight(6,8,34+i,spacing)
    
    surf(xgrid2_case4(i,:)/1000,alt_case4(:,i)/1000,-vort_y_case4(:,:,i)','FaceColor','interp','Edgecolor','none')    
    caxis(clims_vort_y)
    colormap(map); 
    ylim([76 83]) 
    xlim([min_x(i) max_x(i)]); 
    xlim([min_x(i) max_x(i)])   
    if i == 1
        str1 = {'5.3 $T_B$'};
    elseif i == 2
        str1 = {'6.0 $T_B$'};
    elseif i == 3
        str1 = {'6.8 $T_B$'};
    elseif i == 4
        str1 = {'7.3 $T_B$'};
    end   
    annotation('textbox',dim5{i+1},'String',str1,'FitBoxToText','on',...
    'interpreter','latex','fontsize',12,'EdgeColor','none');
    set(gca,'fontsize',10,'xtick',5:5:20,'ytick',76:2:82)
    grid off
    box on
    set(gca,'layer','top','LineWidth',0.3);
    if i == 3
        ylabel('Alt (km)','fontsize',14) 
        set(gca,'xtick',0:5:20)
    end
    if i > 3
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('Case 4','color',[0,0,0],'fontsize',14);
        set(gca,'ytick',76:2:82);
    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90)
    set(gca,'xtick',round(min_x(i)+5:5:max_x(i)-5))
    set(gca,'xticklabels',[]);
    
    clearvars('vort_y_double','theta_prime_double', 'vort_y', 'theta_prime','u_prime','w_prime','p_prime','vort_mag','theta_prime','rho_prime','u_full','shear','theta_full','n2','u_full_vort','w_full_vort')
end


for i = 3:num_files

% first row of plots
%    subplot_tight(6,8,10+i,spacing)
% second row of plots
%    subplot_tight(6,8,18+i,spacing)
% third row of plots
    subplot_tight(6,8,26+i,spacing)
% fourth row of plots    
%    subplot_tight(6,8,34+i,spacing)
    
    surf(xgrid2_case3(i,:)/1000,alt_case3(:,i)/1000,-vort_y_case3(:,:,i)','FaceColor','interp','Edgecolor','none')    
    caxis(clims_vort_y)
    colormap(map); 
    ylim([76 83]) 
    xlim([min_x(i) max_x(i)]); 
    if i == 1
        str1 = {'5.3 $T_B$'};
    elseif i == 2
        str1 = {'6.0 $T_B$'};
    elseif i == 3
        str1 = {'6.8 $T_B$'};
    elseif i == 4
        str1 = {'7.3 $T_B$'};
    end
    annotation('textbox',dim4{i+1},'String',str1,'FitBoxToText','on',...
    'interpreter','latex','fontsize',12,'EdgeColor','none');
    set(gca,'fontsize',10,'xtick',5:5:20,'ytick',76:2:82)
    grid off
    box on
    set(gca,'layer','top','LineWidth',0.3,'xticklabels',[]);
    if i == 3
        ylabel('Alt (km)','fontsize',14) 
        set(gca,'xtick',0:5:20)
    end
    if i > 3
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('Case 3','color',[0,0,0],'fontsize',14);
        set(gca,'ytick',76:2:82,'xticklabels',[]);
    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    set(gca,'xticklabels',[]);
    view(0,90); set(gca,'xtick',round(min_x(i)+5:5:max_x(i)-5)) 
    
    clearvars('vort_y_double','theta_prime_double', 'vort_y', 'theta_prime','u_prime','w_prime','p_prime','vort_mag','theta_prime','rho_prime','u_full','shear','theta_full','n2','u_full_vort','w_full_vort')
end
    
 


