
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure7_r.m                                                             %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 7 right panels                                             %
%                                                                         %
%   required input files:                                                 %
%       figure7r_data.mat                                                 %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc
   
set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

load figure7r_data.mat

spacing = [.015 0];

clims_theta = [-0.12 0.12];
clims_vort_y = [-.3 .3];
clims_w = [-40 40];
clims_solenoid = [-.006 .006];

min_y = [76 76 76 76];
max_y = [82 82 82 82];

min_x = [12 10 9 8];
max_x = [22 20 19 18];

clims_shear = [0 .1]; 
clims_n2 = [0 .002];

dim{1} = [0.61 0.525 0.1 0.3];
dim{2} = [0.69 0.525 0.1 0.3];
dim{3} = [0.77 0.525 0.1 0.3];
dim{4} = [0.85 0.525 0.1 0.3];

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];    
colormap(map); 

num_files = 4;

for i = 1:num_files
    
    % first row of plots
    %subplot_tight(6,8,10+i,spacing)
    % second row of plots
    subplot_tight(6,12,19+i,spacing)
    % third row of plots
    %subplot_tight(6,8,26+i,spacing)
    % fourth row of plots    
    %subplot_tight(6,8,34+i,spacing)

    surf(xgrid2_case4(i,:)/1000,alt_case4(:,i)/1000,theta_prime_case4(:,:,i)','FaceColor','interp','Edgecolor','none')
    caxis(clims_theta);
    colormap(map); 
    ylim([min_y(i) max_y(i)]) 
    xlim([min_x(i) max_x(i)])
    if i == 1
        set(gca,'yticklabels',[]);
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        set(gca,'yticklabels',[]); c = colorbar;
        c.FontSize = 10;
        c.Location = 'west';
        c.Label.Interpreter = 'latex';
        c.Label.String = '$\theta''/\ \overline{\theta}$'; 
        c.Label.FontSize = 14;
        c.Label.FontWeight = 'bold';
    end
        set(gca,'xtick',round(min_x(i)+1:2:max_x(i)-1),'xticklabels', ' ')
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90);  box on;  grid off
    set(gca,'fontsize',10,'layer','top','LineWidth',0.3)
   
    % first row of plots
    %subplot_tight(6,8,10+i,spacing)
    % second row of plots
    %subplot_tight(6,8,18+i,spacing)
    % third row of plots
   subplot_tight(6,12,31+i,spacing)
    % fourth row of plots    
    %subplot_tight(6,8,34+i,spacing)
    
    surf(xgrid2_case4(i,:)/1000,alt_case4(:,i)/1000,vort_y_case4(:,:,i)','FaceColor','interp','Edgecolor','none') 
    caxis(clims_vort_y)
    colormap(map); 
    ylim([min_y(i) max_y(i)]) 
    xlim([min_x(i) max_x(i)])
 
    if i == 1
        set(gca,'yticklabels',[]);
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        set(gca,'yticklabels',[]); c = colorbar;
        c.FontSize = 10;
        c.Location = 'west';
        c.Label.String = '$\zeta_y$'; 
        c.Label.FontSize = 14;
        c.Label.FontWeight = 'bold';
        c.Label.Interpreter = 'latex';
    end
    set(gca,'xtick',round(min_x(i)+1:2:max_x(i)-1),'xticklabels', ' ')
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90);  box on;  grid off
    set(gca,'fontsize',10,'layer','top','LineWidth',0.3)
    
    % first row of plots
    %subplot_tight(6,8,10+i,spacing)
    % second row of plots
    %subplot_tight(6,8,18+i,spacing)
    % third row of plots
    %subplot_tight(6,8,26+i,spacing)
    % fourth row of plots    
    subplot_tight(6,12,43+i,spacing)

    surf(xgrid2_case4(i,:)/1000,altcs_case4(:,i)/1000,sol_case4(1:1024,:,i)','FaceColor','interp','Edgecolor','none')
    caxis(clims_solenoid)
    colormap(map);
    ylim([min_y(i) max_y(i)]) 
    xlim([min_x(i) max_x(i)])
   if i == 1
        set(gca,'yticklabels',[]);
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2); set(gca,'ytick',77.7:2:81.7);
        set(gca,'yticklabels',[]); c = colorbar;
        c.FontSize = 10;
        c.Location = 'west';
        c.Label.Interpreter = 'latex';
        c.Label.String = '$\frac{1}{\rho^2}\ \left(\nabla \rho \times \nabla p \right)_y$'; 
        c.Label.FontSize = 14;
        c.Label.FontWeight = 'bold';
        xlabel('Spanwise Domain (km)','color',[0,0,0],'fontsize',14);
        set(gca,'ytick',70:5:90);
    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90);  box on;  grid off
    set(gca,'xtick',round(min_x(i)+1:4:max_x(i)-1),'xticklabels', {-4,0,4})
    set(gca,'fontsize',10,'layer','top','LineWidth',0.3)    
    if i == 1
        str1 = {'7.0 $T_B$'};
    elseif i == 2
        str1 = {'7.2 $T_B$'};
    elseif i == 3
        str1 = {'7.4 $T_B$'};
    elseif i == 4
        str1 = {'7.6 $T_B$'};
    end
    annotation('textbox',dim{i},'String',str1,'FitBoxToText','on',...
        'interpreter','latex','fontsize',12,'EdgeColor','none');
end

