
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 
% figure8_l.m                                                             %
% Tyler Mixa, 11 July 2019                                                %
% plots figure 8 left panels                                              %
%                                                                         %
%   required input files:                                                 %
%       fig8l_data.mat                                                    %
%                                                                         %
%   required scripts:                                                     %
%       subplot_tight.m                                                   %
%                                                                         %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 


clearvars
close all
clc
   
set(0,'DefaultFigureWindowStyle','docked')
set(0,'DefaultTextInterpreter', 'latex')

load figure8l_data.mat

spacing = [.015 0];

clims_theta = [-0.12 0.12];
clims_vort_y = [-.3 .3];
clims_w = [-40 40];
clims_solenoid = [-.006 .006];


min_y = [77 77 77 77];
max_y = [83 83 83 83];

min_x = [2 0 19 16.5];
max_x = [13 11 30 27.5]; 

clims_shear = [0 .1]; 
clims_n2 = [0 .002];

dim{1} = [0.19 0.525 0.1 0.3];
dim{2} = [0.27 0.525 0.1 0.3];
dim{3} = [0.35 0.525 0.1 0.3];
dim{4} = [0.44 0.525 0.1 0.3];

% set red-offwhitegray-blue colormap
num_contours = 500;
column1 = [0:.9/num_contours:.9,.9+.1/num_contours:.1/num_contours:1]';
column2 = [0:.9/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
column3 = [1:-.1/num_contours:.9,.9-.9/num_contours:-.9/num_contours:0]';
map = [column1,column2,column3];
colormap(map); 

num_files = 4;

for i = 1:num_files
       
    % first row of plots
    %subplot_tight(6,8,10+i,spacing)
    % second row of plots
    subplot_tight(6,12,14+i,spacing)
    % third row of plots
    %subplot_tight(6,8,26+i,spacing)
    % fourth row of plots    
    %subplot_tight(6,8,34+i,spacing)
    
    surf(xgrid2_case5(i,:)/1000,alt_case5(:,i)/1000,theta_prime_case5(:,:,i)','FaceColor','interp','Edgecolor','none')
    caxis(clims_theta);
    colormap(map); 
    ylim([min_y(i) max_y(i)]) 
    xlim([min_x(i) max_x(i)])
    if i == 1
        ylabel('Alt (km)','fontsize',14) 
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('$\theta''/\ \overline{\theta}$','color',[0,0,0],'fontsize',14);
        set(gca,'ytick',70:5:90);
    end
        set(gca,'xtick',round(min_x(i)+1:2:max_x(i)-1),'xticklabels', ' ')
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90); box on;  grid off
    set(gca,'fontsize',10,'layer','top','LineWidth',0.3)

    
    % first row of plots
    %subplot_tight(6,8,10+i,spacing)
    % second row of plots
    %subplot_tight(6,8,18+i,spacing)
    % third row of plots
   subplot_tight(6,12,26+i,spacing)
    % fourth row of plots    
    %subplot_tight(6,8,34+i,spacing)

    surf(xgrid2_case5(i,:)/1000,alt_case5(:,i)/1000,vort_y_case5(:,:,i)','FaceColor','interp','Edgecolor','none')
    caxis(clims_vort_y)
    colormap(map); 
    ylim([min_y(i) max_y(i)]) 
    xlim([min_x(i) max_x(i)])
    if i == 1
        ylabel('Alt (km)','fontsize',14) 
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('$\zeta_y$','color',[0,0,0],'fontsize',14);
        set(gca,'ytick',70:5:90);
    end
    set(gca,'xtick',round(min_x(i)+1:2:max_x(i)-1),'xticklabels', ' ')
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90); box on;  grid off
    set(gca,'fontsize',10,'layer','top','LineWidth',0.3)
        
    % first row of plots
    %subplot_tight(6,8,10+i,spacing)
    % second row of plots
    %subplot_tight(6,8,18+i,spacing)
    % third row of plots
    %subplot_tight(6,8,26+i,spacing)
    % fourth row of plots    
    subplot_tight(6,12,38+i,spacing)

    surf(xgrid2_case5(i,:)/1000,altcs_case5(:,i)/1000,sol_case5(:,:,i)','FaceColor','interp','Edgecolor','none')
   
   
    caxis(clims_solenoid)
    colormap(map); 
    ylim([min_y(i) max_y(i)]) 
    xlim([min_x(i) max_x(i)])
    if i == 1
        ylabel('Alt (km)','fontsize',14) 
    end
    if i > 1
        set(gca,'yticklabels',[]);
    end
    if i == num_files 
        view(2)
        yyaxis right
        ax = gca;
        ax.YAxis(2).Color = [0,0,0];
        ylabel('$\frac{1}{\rho^2}\ \left(\nabla \rho \times \nabla p \right)_y$','color',[0,0,0],'fontsize',14);
        xlabel('Spanwise Domain (km)','color',[0,0,0],'fontsize',14);
        set(gca,'ytick',70:5:90);
    end
    ax = gca;
    ax.XColor = [0 0 0];
    ax.YColor = [0 0 0];
    view(0,90); box on;  grid off
    set(gca,'xtick',round(min_x(i)+1:4:max_x(i)-1),'xticklabels', {-4,0,4})
    set(gca,'fontsize',10,'layer','top','LineWidth',0.3)
    if i == 1
        str1 = {'5.3 $T_B$'};
    elseif i == 2
        str1 = {'5.5 $T_B$'};
    elseif i == 3
        str1 = {'5.7 $T_B$'};
    elseif i == 4
        str1 = {'5.9 $T_B$'};
    end
    annotation('textbox',dim{i},'String',str1,'FitBoxToText','on',...
        'interpreter','latex','fontsize',12,'EdgeColor','none');
end

